@@ -28,6 +28,7 @@ from functools import partial
 from copy import deepcopy
 from tqdm import tqdm
 import sys
+from time import sleep
 from greedyFAS.mainFAS.fasInput import read_json
 from greedyFAS.mainFAS.fasOutput import write_domain_out
 from greedyFAS.mainFAS.fasOutput import write_tsv_out
@@ -129,12 +130,12 @@ def fc_start(option):
         r_results = fc_main(domain_count_2, query_proteome, seed_proteome, clan_dict, option)
         if option["phyloprofile"]:
             phyloprofile_out(option["outpath"], True, option["phyloprofile"], (f_results, r_results))
-        if not option['output']:
+        if not option['tsv']:
             write_tsv_out(option["outpath"], True, (f_results, r_results))
     else:
         print("calculating forward scores...")
         results = fc_main(domain_count, seed_proteome, query_proteome, clan_dict, option)
-        if not option["output"]:
+        if not option["tsv"]:
             write_tsv_out(option["outpath"], False, (results, None))
         if option["phyloprofile"]:
             phyloprofile_out(option["outpath"], False, option["phyloprofile"], [results, None])
@@ -157,12 +158,11 @@ def fc_main(domain_count, seed_proteome, query_proteome, clan_dict, option):
     progress = None
     domain_out = None
     results = []
-    if not option["output"]:
-        if option["domain"]:
-            if option["reverse"]:
-                domain_out = open(option["outpath"] + "_reverse.domains", "w")
-            else:
-                domain_out = open(option["outpath"] + "_forward.domains", "w")
+    if option["domain"]:
+        if option["reverse"]:
+            domain_out = open(option["outpath"] + "_reverse.domains", "w")
+        else:
+            domain_out = open(option["outpath"] + "_forward.domains", "w")
     if option['pairwise']:
         if option['progress']:
             progress = tqdm(total=len(option['pairwise']), file=sys.stdout)
@@ -201,6 +201,9 @@ def fc_main(domain_count, seed_proteome, query_proteome, clan_dict, option):
                                            query, query_clans, domain_out))
                 if option["progress"]:
                     progress.update(1)
+        progress.refresh()
+        progress.close()
+        sleep(1.0)
     return results
 
 
@@ -225,7 +228,7 @@ def fc_prep_query(query, domain_count, query_proteome, option, clan_dict):
     else:
         all_query_paths = "NOPRIORITY"
     return tmp_query_graph, all_query_paths, lin_query_set, query_features, a_q_f, query_clans, clan_dict, \
-           go_priority, domain_count
+        go_priority, domain_count
 
 
 def fc_main_sub(protein, domain_count, seed_proteome, option, all_query_paths, query_features, go_priority, a_q_f,
@@ -420,39 +423,38 @@ def fc_main_sub(protein, domain_count, seed_proteome, option, all_query_paths, q
                                     query_features[feature][2], query_features[feature][3]))
         else:
             best_query_path.append((a_q_f[feature][0], a_q_f[feature][1], a_q_f[feature][2], a_q_f[feature][3]))
-    if not option["output"]:
-        path_tmp = {}
-        path_tmp_query = {}
-        scale = 0
-        if option["weight_const"] == 1:
-            path_tmp2 = []
-            for feature in best_template_path:
-                if feature[0] not in path_tmp2:
-                    path_tmp2.append(feature[0])
-            adjusted_weights = w_weight_const_rescale(path_tmp2, weights, search_features, True, option)
-            for adj_feature in adjusted_weights:
-                weights[adj_feature] = adjusted_weights[adj_feature]
+    path_tmp = {}
+    path_tmp_query = {}
+    scale = 0
+    if option["weight_const"] == 1:
+        path_tmp2 = []
         for feature in best_template_path:
-            if feature[0] in path_tmp:
-                path_tmp[feature[0]].append((feature[2], feature[3]))
-            else:
-                path_tmp[feature[0]] = [(feature[2], feature[3])]
-                if option["MS_uni"] == 0:
-                    scale += weights[feature[0]]
-        for feature in best_query_path:
-            if feature[0] in path_tmp_query:
-                path_tmp_query[feature[0]].append((feature[2], feature[3]))
-            else:
-                path_tmp_query[feature[0]] = [(feature[2], feature[3])]
+            if feature[0] not in path_tmp2:
+                path_tmp2.append(feature[0])
+        adjusted_weights = w_weight_const_rescale(path_tmp2, weights, search_features, True, option)
+        for adj_feature in adjusted_weights:
+            weights[adj_feature] = adjusted_weights[adj_feature]
+    for feature in best_template_path:
+        if feature[0] in path_tmp:
+            path_tmp[feature[0]].append((feature[2], feature[3]))
+        else:
+            path_tmp[feature[0]] = [(feature[2], feature[3])]
+            if option["MS_uni"] == 0:
+                scale += weights[feature[0]]
+    for feature in best_query_path:
+        if feature[0] in path_tmp_query:
+            path_tmp_query[feature[0]].append((feature[2], feature[3]))
+        else:
+            path_tmp_query[feature[0]] = [(feature[2], feature[3])]
 
-        # unweighted case
-        if option["MS_uni"] == 0:
-            if scale > 0:
-                scale = 1.0 / float(scale)
-            else:
-                scale = 1.0
-        if option["domain"]:
-            write_domain_out(seed_proteome, query_proteome, protein, query, weights, scale, path_tmp, path_tmp_query,
+    # unweighted case
+    if option["MS_uni"] == 0:
+        if scale > 0:
+            scale = 1.0 / float(scale)
+        else:
+            scale = 1.0
+    if option["domain"]:
+        write_domain_out(seed_proteome, query_proteome, protein, query, weights, scale, path_tmp, path_tmp_query,
                              domain_out, option)
     if option["raw"]:
         print('#' + '\t' + protein + '\t' + query + '\t' + str(score[3]))
@@ -726,8 +728,6 @@ def pb_calc_sub(protein, search_features, weights, query_features, seed_proteome
     :param a_q_f: additional query features [non linearized]
     :param clan_dict: dictionary that maps features to clans
     :param query_clans: (Pfam)-clans of the current query protein
-    :param timelimit: the amount of time this job is allowed to take before the calculation is stopped and priority
-                      mode is used instead
     :param option: dictionary that contains the main option variables of FAS
     :param jobpaths: a group of (query) paths to be evaluated
     :param search_path_number: number of paths in search protein
@@ -776,9 +776,6 @@ def pb_entire_main_nongreedy(protein_id, query_path, search_features, weights, q
     :return: path_score, mode[priority or extensive]
 
     """
-    path_score = 0
-    mode = 0
-
     if (int(len(search_features)) >= option["priority_threshold"] or search_path_number > option['max_cardinality']) \
             and option["priority_mode"]:
         mode = 1
@@ -869,7 +866,6 @@ def pb_entire_graphtraversal(search_graph, query_path, search_features, weights,
                     if (score_w[4] >= best_path[1][4] and score_w[3] == best_path[1][3]) or \
                        score_w[3] >= best_path[1][3]:
                         best_path = (path_ad, score_w, query_path_ad)
-                    first = 0
                 else:
                     v_stack.append(next_vertex)
                     p_stack.append(path + [next_vertex])
